@@ -1,4 +1,4 @@
-# Copyright (c) 2010 Twisted Matrix Laboratories.
+# Copyright (c) 2010 Jan Urbanski.
 # See LICENSE for details.
 
 """
@@ -24,8 +24,8 @@ CREATE TABLE simple (
 
 DB_NAME = "twisted_test"
 DB_HOST = "localhost"
-DB_USER = "wulczer"
-DB_PASS = ""
+DB_USER = "twisted_test"
+DB_PASS = "twisted_test"
 
 
 def getSkipForPsycopg2():
@@ -34,12 +34,16 @@ def getSkipForPsycopg2():
     try:
         psycopg2.extensions.POLL_OK
     except AttributeError:
-        return ("psycopg2 does not have async support")
+        return ("psycopg2 does not have async support. "
+                "You need at least version 2.2.0 of psycopg2 "
+                "to use txpostgres.")
     try:
         psycopg2.connect(user=DB_USER, password=DB_PASS,
                          host=DB_HOST, database=DB_NAME).close()
     except psycopg2.Error:
-        return "cannot connect to test database"
+        return ("cannot connect to test database %r "
+                "using host %r, user %r and password %r" %
+                (DB_NAME, DB_HOST, DB_USER, DB_PASS))
     return None
 
 
@@ -183,8 +187,8 @@ class TxPostgresPollingMixingTestCase(Psycopg2TestCase):
 
     def test_errors(self):
         """
-        Unexpected results from poll() make L{txpostgres._PollingMixin} raise an
-        exception.
+        Unexpected results from poll() make L{txpostgres._PollingMixin} raise
+        an exception.
         """
         p = FakeWrapper()
         p._pollable = PollableThing()
@@ -302,7 +306,6 @@ class _SimpleDBSetupMixin(object):
         return d.addCallback(lambda _: self.conn.close())
 
 
-
 class TxPostgresManualQueryTestCase(_SimpleDBSetupMixin, Psycopg2TestCase):
 
     def test_simpleQuery(self):
