@@ -1,5 +1,5 @@
-# -*- test-case-name: twisted.test.test_pgadbapi -*-
-# Copyright (c) 2010 Twisted Matrix Laboratories.
+# -*- test-case-name: test.test_txpostgres -*-
+# Copyright (c) 2010 Jan Urbanski.
 # See LICENSE for details.
 
 """
@@ -15,6 +15,16 @@ from twisted.internet import interfaces, reactor, defer
 from twisted.python import log
 
 
+try:
+    psycopg2.extensions.POLL_OK
+except AttributeError:
+    import warnings
+    warnings.warn(RuntimeWarning(
+            "psycopg2 does not have async support. "
+            "You need at least version 2.2.0 of psycopg2 "
+            "to use txpostgres."))
+
+
 class UnexpectedPollResult(Exception):
     """
     Polling returned an unexpected result.
@@ -67,7 +77,7 @@ class _PollingMixin(object):
         try:
             self._pollingState = self.pollable().poll()
         except:
-            d,  self._pollingD = self._pollingD, None
+            d, self._pollingD = self._pollingD, None
             d.errback()
             return ret
 
@@ -79,7 +89,7 @@ class _PollingMixin(object):
         elif self._pollingState == psycopg2.extensions.POLL_READ:
             self.reactor.addReader(self)
         else:
-            d,  self._pollingD = self._pollingD, None
+            d, self._pollingD = self._pollingD, None
             d.errback(UnexpectedPollResult())
 
         return ret
@@ -103,7 +113,7 @@ class _PollingMixin(object):
 
     def connectionLost(self, reason):
         if self._pollingD:
-            d,  self._pollingD = self._pollingD, None
+            d, self._pollingD = self._pollingD, None
             d.errback(reason)
 
     # forward all other access to the underlying connection
@@ -191,8 +201,8 @@ class RollbackFailed(Exception):
     @ivar connection: The connection that failed to roll back its transaction.
 
     @type originalFailure: L{failure.Failure}
-    @ivar originalFailure: The failure that caused the connection to try to roll back
-        the transaction.
+    @ivar originalFailure: The failure that caused the connection to try to
+        roll back the transaction.
     """
 
     def __init__(self, connection, originalFailure):
@@ -358,6 +368,7 @@ class Connection(_PollingMixin):
 
         return d
 
+
 class ConnectionPool(object):
     """
     A poor man's pool of L{pgadbapi.Connection} instances.
